@@ -141,7 +141,15 @@ format_parameters.parameters_model <- function(model, ...) {
 
     if (types$Type[i] %in% c("interaction", "nested", "simple")) {
       # Interaction or nesting
-      components <- unlist(strsplit(name, ":", fixed = TRUE), use.names = FALSE)
+
+      # for "serp" models, coefficients end with ":1", ":2", etc. - we need
+      # to take this into account when splitting the name into components.
+      if (inherits(model, "serp")) {
+        pattern <- "(:(?![0-9]+$))"
+        components <- unlist(strsplit(name, pattern, perl = TRUE), use.names = FALSE)
+      } else {
+        components <- unlist(strsplit(name, ":", fixed = TRUE), use.names = FALSE)
+      }
       is_nested <- types$Type[i] == "nested"
       is_simple <- types$Type[i] == "simple"
 
@@ -319,11 +327,11 @@ format_parameters.parameters_model <- function(model, ...) {
   if (all(grepl(pattern_cut_right, level))) {
     lower_bounds <- gsub(pattern_cut_right, "\\1", level)
     upper_bounds <- gsub(pattern_cut_right, "\\2", level)
-    level <- paste0(as.numeric(lower_bounds) + 1, "-", upper_bounds)
+    level <- paste0(">", as.numeric(lower_bounds), "-", upper_bounds)
   } else if (all(grepl(pattern_cut_left, level))) {
     lower_bounds <- gsub(pattern_cut_left, "\\1", level)
     upper_bounds <- gsub(pattern_cut_left, "\\2", level)
-    level <- paste0(lower_bounds, "-", as.numeric(upper_bounds) - 1)
+    level <- paste0(lower_bounds, "-<", as.numeric(upper_bounds))
   }
   paste0(variable, " ", brackets[1], level, brackets[2])
 }
