@@ -13,9 +13,9 @@
 #' \donttest{
 #' if (require("BayesFM")) {
 #'   efa <- BayesFM::befa(mtcars, iter = 1000)
-#'   results <- model_parameters(efa, sort = TRUE)
+#'   results <- model_parameters(efa, sort = TRUE, verbose = FALSE)
 #'   results
-#'   efa_to_cfa(results)
+#'   efa_to_cfa(results, verbose = FALSE)
 #' }
 #' }
 #' @return A data frame of loadings.
@@ -77,6 +77,7 @@ model_parameters.befa <- function(model,
             ci = ci,
             ci_method = ci_method,
             test = test,
+            verbose = verbose,
             ...
           )
         rez[1, ] <- NA
@@ -89,6 +90,7 @@ model_parameters.befa <- function(model,
             ci = ci,
             ci_method = ci_method,
             test = test,
+            verbose = verbose,
             ...
           )
       }
