@@ -36,19 +36,22 @@ degrees_of_freedom.complmrob <- function(model, method = "wald", ...) {
 #' @inheritParams model_parameters.aov
 #' @export
 model_parameters.Gam <- function(model,
-                                 omega_squared = NULL,
-                                 eta_squared = NULL,
-                                 epsilon_squared = NULL,
+                                 es_type = NULL,
                                  df_error = NULL,
                                  type = NULL,
                                  table_wide = FALSE,
                                  verbose = TRUE,
+                                 effectsize_type = NULL,
                                  ...) {
+  ## TODO: remove deprecation warning later
+  if (!is.null(effectsize_type)) {
+    insight::format_warning("Argument `effectsize_type` is deprecated. Use `es_type` instead.")
+    es_type <- effectsize_type
+  }
+
   model_parameters(
     summary(model)$parametric.anova,
-    omega_squared = omega_squared,
-    eta_squared = eta_squared,
-    epsilon_squared = epsilon_squared,
+    es_type = es_type,
     df_error = df_error,
     type = type,
     table_wide = table_wide,
