@@ -94,6 +94,7 @@
 #'   so this is just for completeness.
 #' @inheritParams insight::format_table
 #' @inheritParams compare_parameters
+#' @inheritParams display.parameters_model
 #'
 #' @inheritSection format_parameters Interpretation of Interaction Terms
 #' @inheritSection model_parameters Labeling the Degrees of Freedom
@@ -142,13 +143,11 @@
 #' create HTML tables. If set to `tt`, the _tinytable_ package is used.
 #'
 #' @details `summary()` is a convenient shortcut for
-#'   `print(object, select = "minimal", show_sigma = TRUE, show_formula = TRUE)`.
+#' `print(object, select = "minimal", show_sigma = TRUE, show_formula = TRUE)`.
 #'
 #' @return Invisibly returns the original input object.
 #'
-#' @seealso There is a dedicated method to use inside rmarkdown files,
-#'   [`print_md()`][print_md.parameters_model]. See also
-#'   [`display()`][display.parameters_model].
+#' @seealso See also [`display()`][display.parameters_model].
 #'
 #' @examplesIf require("gt", quietly = TRUE) && require("glmmTMB", quietly = TRUE)
 #' \donttest{
@@ -386,7 +385,7 @@ print.parameters_random <- function(x, digits = 2, ...) {
                         ci_width = "auto",
                         ci_brackets = TRUE,
                         format = "text",
-                        group = NULL,
+                        groups = NULL,
                         include_reference = FALSE,
                         ...) {
   format(
@@ -401,7 +400,7 @@ print.parameters_random <- function(x, digits = 2, ...) {
     ci_brackets = ci_brackets,
     zap_small = zap_small,
     format = format,
-    group = group,
+    groups = groups,
     include_reference = include_reference,
     ...
   )
