@@ -1,14 +1,14 @@
 skip_on_cran()
 
-iris$Cat1 <- rep(c("X", "X", "Y"), length.out = nrow(iris))
-iris$Cat2 <- rep(c("A", "B"), length.out = nrow(iris))
+iris$Cat1 <- rep_len(c("X", "X", "Y"), nrow(iris))
+iris$Cat2 <- rep_len(c("A", "B"), nrow(iris))
 
 # aov ----------------------------------
 
 test_that("model_parameters.aov", {
   skip_if_not_installed("effectsize", minimum_version = "0.5.0")
   model <- aov(Sepal.Width ~ Species, data = iris)
-  mp <- suppressMessages(model_parameters(model, effectsize_type = c("omega", "eta", "epsilon")))
+  mp <- suppressMessages(model_parameters(model, es_type = c("omega", "eta", "epsilon")))
   expect_identical(mp$Parameter, c("Species", "Residuals"))
   expect_equal(mp$Sum_Squares, c(11.34493, 16.962), tolerance = 1e-3)
 })
@@ -16,7 +16,7 @@ test_that("model_parameters.aov", {
 test_that("model_parameters.aov", {
   skip_if_not_installed("effectsize", minimum_version = "0.5.0")
   model <- aov(Sepal.Width ~ Species, data = iris)
-  mp <- suppressMessages(model_parameters(model, effectsize_type = c("omega", "eta", "epsilon")))
+  mp <- suppressMessages(model_parameters(model, es_type = c("omega", "eta", "epsilon")))
   expect_identical(sum(mp$df), 149)
   expect_named(mp, c(
     "Parameter", "Sum_Squares", "df", "Mean_Square", "F", "p",
@@ -24,7 +24,7 @@ test_that("model_parameters.aov", {
   ))
 
   model <- aov(Sepal.Length ~ Species * Cat1 * Cat2, data = iris)
-  expect_identical(sum(model_parameters(model, effectsize_type = c("omega", "eta", "epsilon"), verbose = FALSE)$df), 149)
+  expect_identical(sum(model_parameters(model, es_type = c("omega", "eta", "epsilon"), verbose = FALSE)$df), 149)
 
   model <- aov(Sepal.Length ~ Species / Cat1 * Cat2, data = iris)
   expect_identical(sum(model_parameters(model, verbose = FALSE)$df), 149)
